@@ -4,7 +4,7 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#include <configurationproxy.h>
+#include "configurationproxy.h"
 
 ConfigurationProxy::ConfigurationProxy(QObject *parent)
     : QObject(parent)
