@@ -53,6 +53,7 @@ ConnectionWidget::ConnectionWidget(const NetworkManager::ConnectionSettings::Ptr
 
     connect(m_widget->autoconnect, &QCheckBox::stateChanged, this, &ConnectionWidget::settingChanged);
     connect(m_widget->allUsers, &QCheckBox::stateChanged, this, &ConnectionWidget::settingChanged);
+    connect(m_widget->allUsers, &QCheckBox::stateChanged, this, &ConnectionWidget::allUsersChanged);
     connect(m_widget->autoconnectVpn, &QCheckBox::stateChanged, this, &ConnectionWidget::settingChanged);
     connect(m_widget->pushButtonPermissions, &QPushButton::clicked, this, &ConnectionWidget::settingChanged);
     connect(m_widget->firewallZone, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &ConnectionWidget::settingChanged);
@@ -141,6 +142,11 @@ NMVariantMapMap ConnectionWidget::setting() const
     return settings.toMap();
 }
 
+bool ConnectionWidget::allUsers() const
+{
+    return m_widget->allUsers->isChecked();
+}
+
 void ConnectionWidget::autoVpnToggled(bool on)
 {
     m_widget->vpnCombobox->setEnabled(on);
@@ -165,7 +171,7 @@ NMStringMap ConnectionWidget::vpnConnections() const
         NetworkManager::ConnectionSettings::Ptr conSet = conn->settings();
         if (conSet->connectionType() == NetworkManager::ConnectionSettings::Vpn //
             || conSet->connectionType() == NetworkManager::ConnectionSettings::WireGuard) {
-            // qCDebug(PLASMA_NM) << "Found VPN" << conSet->id() << conSet->uuid();
+            // qCDebug(PLASMA_NM_EDITOR_LOG) << "Found VPN" << conSet->id() << conSet->uuid();
             result.insert(conSet->uuid(), conSet->id());
         }
     }
@@ -175,16 +181,16 @@ NMStringMap ConnectionWidget::vpnConnections() const
 
 QStringList ConnectionWidget::firewallZones() const
 {
-    QDBusMessage msg = QDBusMessage::createMethodCall("org.fedoraproject.FirewallD1", //
-                                                      "/org/fedoraproject/FirewallD1",
-                                                      "org.fedoraproject.FirewallD1.zone",
-                                                      "getZones");
+    QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.fedoraproject.FirewallD1"), //
+                                                      QStringLiteral("/org/fedoraproject/FirewallD1"),
+                                                      QStringLiteral("org.fedoraproject.FirewallD1.zone"),
+                                                      QStringLiteral("getZones"));
     QDBusPendingReply<QStringList> reply = QDBusConnection::systemBus().asyncCall(msg);
     reply.waitForFinished();
     if (reply.isValid())
         return reply.value();
 
-    return QStringList();
+    return {};
 }
 
 void ConnectionWidget::populateVpnConnections()
