@@ -21,12 +21,10 @@
 #include <NetworkManagerQt/Manager>
 #include <NetworkManagerQt/Security8021xSetting>
 
-#if WITH_MODEMMANAGER_SUPPORT
 #include <ModemManagerQt/Manager>
 #include <ModemManagerQt/Modem3Gpp>
 #include <ModemManagerQt/ModemCdma>
 #include <ModemManagerQt/ModemDevice>
-#endif
 
 // Qt
 #include <QHostAddress>
@@ -460,7 +458,6 @@ QString UiUtils::wirelessFrequencyToString(uint frequency)
     return i18nc("Wireless connection frequency", "%1 GHz", frequency / 1000.0);
 }
 
-#if WITH_MODEMMANAGER_SUPPORT
 QString UiUtils::convertAllowedModeToString(ModemManager::Modem::ModemModes modes)
 {
     if (modes.testFlag(MM_MODEM_MODE_4G)) {
@@ -480,7 +477,12 @@ QString UiUtils::convertAllowedModeToString(ModemManager::Modem::ModemModes mode
 
 QString UiUtils::convertAccessTechnologyToString(ModemManager::Modem::AccessTechnologies tech)
 {
-    if (tech.testFlag(MM_MODEM_ACCESS_TECHNOLOGY_LTE)) {
+#if MM_CHECK_VERSION(1, 14, 0)
+    if (tech.testFlag(MM_MODEM_ACCESS_TECHNOLOGY_5GNR)) {
+        return i18nc("Cellular access technology", "5G NR");
+    } else
+#endif
+        if (tech.testFlag(MM_MODEM_ACCESS_TECHNOLOGY_LTE)) {
         return i18nc("Cellular access technology", "LTE");
     } else if (tech.testFlag(MM_MODEM_ACCESS_TECHNOLOGY_EVDOB)) {
         return i18nc("Cellular access technology", "CDMA2000 EVDO revision B");
@@ -559,7 +561,6 @@ QString UiUtils::convertLockReasonToString(MMModemLock reason)
         return i18nc("possible SIM lock reason", "Lock reason unknown.");
     }
 }
-#endif
 
 NetworkManager::ModemDevice::Capability UiUtils::modemSubType(NetworkManager::ModemDevice::Capabilities modemCaps)
 {
@@ -606,6 +607,9 @@ QString UiUtils::labelFromWirelessSecurity(NetworkManager::WirelessSecurityType
     case NetworkManager::SAE:
         tip = i18nc("@label WPA3-SAE security", "WPA3-SAE");
         break;
+    case NetworkManager::Wpa3SuiteB192:
+        tip = i18nc("@label WPA3-EAP-SUITE-B-192 security", "WPA3-EAP-SUITE-B-192");
+        break;
     default:
         tip = i18nc("@label unknown security", "Unknown security type");
         break;
