@@ -8,15 +8,14 @@
 #define PLASMA_NM_HANDLER_H
 
 #include <QDBusInterface>
+#include <QPointer>
 #include <QTimer>
 
+#include <ModemManagerQt/GenericTypes>
 #include <NetworkManagerQt/Connection>
 #include <NetworkManagerQt/ConnectionSettings>
 #include <NetworkManagerQt/Settings>
 #include <NetworkManagerQt/Utils>
-#if WITH_MODEMMANAGER_SUPPORT
-#include <ModemManagerQt/GenericTypes>
-#endif
 
 class Q_DECL_EXPORT Handler : public QObject
 {
@@ -74,21 +73,29 @@ public Q_SLOTS:
     void addAndActivateConnection(const QString &device, const QString &specificParameter, const QString &password = QString());
 
     /**
-     * Returns a code that includes the credentials to a said wifi connection
+     * Request a code that includes the credentials to a said wifi connection
      * Here's some information on how this information is created, it's generally used to put in QR codes to share.
      * https://github.com/zxing/zxing/wiki/Barcode-Contents#wi-fi-network-config-android-ios-11
      *
      * @param connectionPath the d-bus path to the connection we want to read
      * @param ssid the name of the network being displayed
      * @param securityType the authentication protocol used for this specific ssid
+     * @param connectionName the name of the connection
+     * @see wifiCodeReceived
      */
-    QString wifiCode(const QString &connectionPath, const QString &ssid, /*NetworkManager::WirelessSecurityType*/ int securityType) const;
+    void requestWifiCode(const QString &connectionPath,
+                         const QString &ssid,
+                         /*NetworkManager::WirelessSecurityType*/ int securityType,
+                         const QString &connectionName);
 
     /**
      * Adds a new connection
      * @map - NMVariantMapMap with connection settings
      */
     void addConnection(const NMVariantMapMap &map);
+
+    void addConnection(NMConnection *connection);
+
     /**
      * Deactivates given connection
      * @connection - d-bus path of the connection you want to deactivate
@@ -126,9 +133,8 @@ private Q_SLOTS:
     void replyFinished(QDBusPendingCallWatcher *watcher);
     void hotspotCreated(QDBusPendingCallWatcher *watcher);
     void primaryConnectionTypeChanged(NetworkManager::ConnectionSettings::ConnectionType type);
-#if WITH_MODEMMANAGER_SUPPORT
     void unlockRequiredChanged(MMModemLock modemLock);
-#endif
+    void slotRequestWifiCode(QDBusPendingCallWatcher *watcher);
 
 Q_SIGNALS:
     void connectionActivationFailed(const QString &connectionPath, const QString &message);
@@ -136,6 +142,7 @@ Q_SIGNALS:
     void hotspotDisabled();
     void hotspotSupportedChanged(bool hotspotSupported);
     void scanningChanged();
+    void wifiCodeReceived(const QString &data, const QString &connectionName);
 
 private:
     void addAndActivateConnectionDBus(const NMVariantMapMap &map, const QString &device, const QString &specificObject);
@@ -143,9 +150,7 @@ private:
     bool m_hotspotSupported;
     bool m_tmpWirelessEnabled;
     bool m_tmpWwanEnabled;
-#if WITH_MODEMMANAGER_SUPPORT
     QString m_tmpConnectionPath;
-#endif
     QString m_tmpConnectionUuid;
     QString m_tmpDevicePath;
     QString m_tmpSpecificPath;
@@ -160,6 +165,8 @@ private:
     void scheduleRequestScan(const QString &interface, int timeout);
     void incrementScansCount();
     void decrementScansCount();
+
+    QPointer<QDBusPendingCallWatcher> m_requestWifiCodeWatcher;
 };
 
 #endif // PLASMA_NM_HANDLER_H
