@@ -4,8 +4,11 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 #include "networkmodelitem.h"
+#include "networkmodel.h"
 #include "uiutils.h"
 
+#include <unordered_map>
+
 #include <NetworkManagerQt/AdslDevice>
 #include <NetworkManagerQt/BluetoothDevice>
 #include <NetworkManagerQt/BondDevice>
@@ -16,7 +19,6 @@
 #include <NetworkManagerQt/Settings>
 #include <NetworkManagerQt/TeamDevice>
 #include <NetworkManagerQt/VlanDevice>
-#include <NetworkManagerQt/VpnConnection>
 #include <NetworkManagerQt/VpnSetting>
 #include <NetworkManagerQt/WiredDevice>
 #include <NetworkManagerQt/WirelessDevice>
@@ -24,16 +26,41 @@
 
 #include <KLocalizedString>
 
-#if WITH_MODEMMANAGER_SUPPORT
 #include <ModemManagerQt/Manager>
 #include <ModemManagerQt/Modem3Gpp>
 #include <ModemManagerQt/Modem>
 #include <ModemManagerQt/ModemCdma>
 #include <ModemManagerQt/ModemDevice>
-#endif
 
 #include <QStringBuilder>
 
+namespace
+{
+using ConnectionType = NetworkManager::ConnectionSettings::ConnectionType;
+
+static const std::unordered_map<ConnectionType, QString> s_connectionTypeToString{
+    {ConnectionType::Unknown, i18nc("@info:tooltip", "The connection type is Unknown")},
+    {ConnectionType::Adsl, i18nc("@info:tooltip", "The connection type is ADSL")},
+    {ConnectionType::Bluetooth, i18nc("@info:tooltip", "The connection type is Bluetooth")},
+    {ConnectionType::Bridge, i18nc("@info:tooltip", "The connection type is Bridge")},
+    {ConnectionType::Cdma, i18nc("@info:tooltip", "The connection type is CDMA")},
+    {ConnectionType::Gsm, i18nc("@info:tooltip", "The connection type is GSM")},
+    {ConnectionType::Infiniband, i18nc("@info:tooltip", "The connection type is Infiniband")},
+    {ConnectionType::OLPCMesh, i18nc("@info:tooltip", "The connection type is OLPC Mesh")},
+    {ConnectionType::Pppoe, i18nc("@info:tooltip", "The connection type is PPOPE")},
+    {ConnectionType::Vlan, i18nc("@info:tooltip", "The connection type is VLAN")},
+    {ConnectionType::Vpn, i18nc("@info:tooltip", "The connection type is VPN")},
+    {ConnectionType::Wimax, i18nc("@info:tooltip", "The connection type is Wimax")},
+    {ConnectionType::Wired, i18nc("@info:tooltip", "The connection type is Wired")},
+    {ConnectionType::Wireless, i18nc("@info:tooltip", "The connection type is Wireless")},
+    {ConnectionType::Team, i18nc("@info:tooltip", "The connection type is Team")},
+    {ConnectionType::Generic, i18nc("@info:tooltip", "The connection type is Generic")},
+    {ConnectionType::Tun, i18nc("@info:tooltip", "The connection type is Tunnel")},
+    {ConnectionType::IpTunnel, i18nc("@info:tooltip", "The connection type is IP Tunnel")},
+    {ConnectionType::WireGuard, i18nc("@info:tooltip", "The connection type is WireGuard")},
+};
+}
+
 NetworkModelItem::NetworkModelItem(QObject *parent)
     : QObject(parent)
     , m_connectionState(NetworkManager::ActiveConnection::Deactivated)
@@ -410,12 +437,27 @@ void NetworkModelItem::setTimestamp(const QDateTime &date)
 
 void NetworkModelItem::setType(NetworkManager::ConnectionSettings::ConnectionType type)
 {
-    if (m_type != type) {
-        m_type = type;
-        m_changedRoles << NetworkModel::TypeRole << NetworkModel::ItemTypeRole << NetworkModel::UniRole;
-
-        refreshIcon();
+    if (m_type == type) {
+        return;
     }
+
+    m_type = type;
+
+    const auto it = s_connectionTypeToString.find(type);
+    if (it != s_connectionTypeToString.end()) {
+        m_accessibleDescription = it->second;
+    } else {
+        m_accessibleDescription = s_connectionTypeToString.at(NetworkManager::ConnectionSettings::ConnectionType::Unknown);
+    }
+
+    m_changedRoles << NetworkModel::TypeRole << NetworkModel::ItemTypeRole << NetworkModel::UniRole << Qt::AccessibleDescriptionRole;
+
+    refreshIcon();
+}
+
+QString NetworkModelItem::accessibleDescription() const
+{
+    return m_accessibleDescription;
 }
 
 QString NetworkModelItem::uni() const
@@ -618,7 +660,6 @@ void NetworkModelItem::updateDetails() const
             m_details << i18n("MAC Address") << wirelessDevice->hardwareAddress();
         }
     } else if (m_type == NetworkManager::ConnectionSettings::Gsm || m_type == NetworkManager::ConnectionSettings::Cdma) {
-#if WITH_MODEMMANAGER_SUPPORT
         NetworkManager::ModemDevice::Ptr modemDevice = device.objectCast<NetworkManager::ModemDevice>();
         if (modemDevice) {
             ModemManager::ModemDevice::Ptr modem = ModemManager::findModemDevice(modemDevice->udi());
@@ -641,7 +682,6 @@ void NetworkModelItem::updateDetails() const
                 }
             }
         }
-#endif
     } else if (m_type == NetworkManager::ConnectionSettings::Vpn) {
         m_details << i18n("VPN plugin") << m_vpnType;
 
